@@ -16,11 +16,11 @@ OC.L10N.register(
     "Group or team" : "Група або каманда",
     "Folder name" : "Назва папкі",
     "Quota" : "Квота",
+    "Previous" : "Папярэдняя",
     "User" : "Карыстальнік",
     "Unknown" : "Невядомы",
     "None" : "Няма",
     "{displayName} (team)" : "{displayName} (каманда)",
-    "{size} used" : "Выкарыстана {size}",
-    "Group folder" : "Папка групы"
+    "{size} used" : "Выкарыстана {size}"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
