@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "You cannot remove your own read permission." : "Není možné odebrat si sám sobě oprávnění pro čtení.",
     "Team folders" : "Týmové složky",
+    "Team Folders" : "Týmové složky",
     "Unset" : "Zrušit nastavení",
     "Denied (Inherited permission)" : "Odepřeno (převzaté oprávnění)",
     "Allowed (Inherited permission)" : "Umožněno (převzaté oprávnění)",
@@ -61,21 +62,6 @@ OC.L10N.register(
     "Add group or team" : "Přidat skupinu nebo tým",
     "{size} used" : "{size} použito",
     "Other …" : "Ostatní...",
-    "You can not remove your own read permission." : "Není možné odebrat si sám sobě oprávnění pro čtení.",
-    "Group folders" : "Skupinové složky",
-    "Admin configured folders shared with everyone in a group" : "Správcem nastavené složky sdílené s každým ve skupině",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Správce nastavil složky sdílené s kýmkoli ve skupině.\n\nSložky je možné nastavovat ze *Skupinové složky* v nastavení správy.\n\nPo vytvoření složky, správce může udělit přístup do ní jedné či více skupinám, řídit jejich oprávnění k zápisu/sdílení a přiřazovat kvótu pro složku.\n\nPozn.: Šifrování obsahu skupinových složek není v tuto chvíli podporováno.",
-    "Group folder" : "Skupinová složka",
-    "Open group folder" : "Otevřít skupinovou složku",
-    "List of group folders." : "Seznam skupinových složek.",
-    "No group folders yet" : "Zatím žádné skupinové složky",
-    "Group folders will show up here" : "Skupinové složky se zobrazí zde",
-    "Group folder admin delegation" : "Pověření správou skupinových složek",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud umožňuje delegovat správu skupinových složek na uživatele, kteří nejsou správci celého Nextcloud.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Níže zadejte skupiny, kterým bude umožněno spravovat skupinové složky a používat jejich API/REST.",
-    "They will have access to all group folders." : "Budou mít přístup ke všem skupinovým složkám.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Níže zadejte skupiny, pouze kterým bude umožněno spravovat skupinové složky a používat jejich API/REST.",
-    "They will only have access to group folders for which they have advanced permissions." : "Budou mít přístup pouze k těm skupinovým složkám, ke kterým mají pokročilá přístupová oprávnění.",
     "Admin configured folders shared with everyone in a team" : "Správcem nastavené složky sdílené s každým v týmu",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Správcem nastavované složky sdílené s kýmkoli v týmu.\n\nSložky je možné nastavovat z *Týmové složky* v nastavení správy.\n\nPo vytvoření složky, správce může udělit přístup do ní jednomu či vícero týmům, řídit jejich oprávnění k zápisu/sdílení a přiřazovat kvótu pro složku.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Správcem nastavené složky sdílené se všemi v týmu.\n\nSložky mohou být nastaveny v záložce „Týmové složky“ (v nastavení pro správce).\n\nPo vytvoření složky k ní může správce udělit přístup jednomu nebo více týmům, nastavovat jejich možnosti zapisování a sdílení a kvótu.\nPočínaje verzí Hub 10/Nextcloud 31 je třeba, aby správce byl součástí týmu, ke kterému chce složku přiřadit."
