@@ -61,21 +61,6 @@ OC.L10N.register(
     "Add group or team" : "Add group or team",
     "{size} used" : "{size} used",
     "Other …" : "Other …",
-    "You can not remove your own read permission." : "You can not remove your own read permission.",
-    "Group folders" : "Group folders",
-    "Admin configured folders shared with everyone in a group" : "Admin configured folders shared with everyone in a group",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder.",
-    "Group folder" : "Group folder",
-    "Open group folder" : "Open group folder",
-    "List of group folders." : "List of group folders.",
-    "No group folders yet" : "No group folders yet",
-    "Group folders will show up here" : "Group folders will show up here",
-    "Group folder admin delegation" : "Group folder admin delegation",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud allows you to delegate the administration of group folders to non-admin users.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Specify below the groups that will be allowed to manage group folders and use its API/REST.",
-    "They will have access to all group folders." : "They will have access to all group folders.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Specify below the groups that will be allowed to manage group folders and use its API/REST only.",
-    "They will only have access to group folders for which they have advanced permissions." : "They will only have access to group folders for which they have advanced permissions.",
     "Admin configured folders shared with everyone in a team" : "Admin configured folders shared with everyone in a team",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder."
