@@ -19,7 +19,6 @@ OC.L10N.register(
     "User" : "Usuario",
     "Unknown" : "Desconocido",
     "None" : "Ninguno",
-    "{size} used" : "{size} usados",
-    "Group folders" : "Carpetas de grupo"
+    "{size} used" : "{size} usados"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
