@@ -34,8 +34,6 @@ OC.L10N.register(
     "Unknown" : "Óþekkt",
     "None" : "Ekkert",
     "{size} used" : "{size} notað",
-    "Other …" : "Annað …",
-    "Group folders" : "Möppur hóps",
-    "Admin configured folders shared with everyone in a group" : "Möppur settar upp af kerfisstjóra sem deilt með öllum í hópi"
+    "Other …" : "Annað …"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
