@@ -29,7 +29,6 @@ OC.L10N.register(
     "User" : "Lietotājs",
     "Unknown" : "Nezināms",
     "None" : "Nekas",
-    "{size} used" : "Izmantoti {size}",
-    "Group folders" : "Grupu mapes"
+    "{size} used" : "Izmantoti {size}"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
