@@ -61,21 +61,6 @@ OC.L10N.register(
     "Add group or team" : "Dodaj grupę lub zespół",
     "{size} used" : "Wykorzystane: {size}",
     "Other …" : "Inne …",
-    "You can not remove your own read permission." : "Nie możesz usunąć własnego uprawnienia do odczytu.",
-    "Group folders" : "Katalogi grupowe",
-    "Admin configured folders shared with everyone in a group" : "Skonfigurowane przez administratora katalogi udostępnione wszystkim w grupie",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w grupie.\n\nFoldery można konfigurować z poziomu Folderów grup w ustawieniach administracyjnych. \n\nPo utworzeniu folderu administrator może udzielić dostępu do niego jednej lub kilku grupom, kontrolować ich uprawnienia do zapisu/udostępniania oraz przypisać kwotę dla folderu.",
-    "Group folder" : "Katalog grupowy",
-    "Open group folder" : "Otwórz katalog grupy",
-    "List of group folders." : "Lista katalogów grupowych.",
-    "No group folders yet" : "Nie ma jeszcze katalogów grupowych",
-    "Group folders will show up here" : "Tutaj pojawią się katalogi grupowe",
-    "Group folder admin delegation" : "Delegacja administratora katalogu grupy",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud pozwala delegować administrację Folderów grup użytkownikom niebędącym administratorami.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Określ poniżej grupy, które będą mogły zarządzać Folderami grup i korzystać z ich API/REST.",
-    "They will have access to all group folders." : "Będą mieli dostęp do wszystkich katalogów grupy.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Określ poniżej grupy, które będą mogły zarządzać Folderami grup i korzystać z ich API/REST.",
-    "They will only have access to group folders for which they have advanced permissions." : "Będą mieli dostęp tylko do katalogów grup, do których mają zaawansowane uprawnienia.",
     "Admin configured folders shared with everyone in a team" : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w zespole",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w zespole. \n\nFoldery można konfigurować z poziomu Folderów zespołów w ustawieniach administracyjnych. \n\nPo utworzeniu folderu administrator może udzielić dostępu do niego jednej lub kilku drużynom, kontrolować ich uprawnienia do zapisu/udostępniania oraz przypisać kwotę dla folderu.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w zespole. \n\nFoldery można konfigurować z poziomu Folderów zespołów w ustawieniach administracyjnych. \n\nPo utworzeniu folderu administrator może udzielić dostępu do niego jednemu lub kilku zespołom, kontrolować ich uprawnienia do zapisu/udostępniania oraz przypisać kwotę dla folderu. \nOd wersji Hub 10/Nextcloud 31 administrator musi być członkiem zespołu, aby móc przypisać mu Folder zespołu."
