@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "You cannot remove your own read permission." : "Você não pode remover sua própria permissão de leitura.",
     "Team folders" : "Pastas de equipe",
+    "Team Folders" : "Pastas de Equipe",
+    "Shared folders managed by admins, accessible to designated teams with configurable permissions and quotas" : "Pastas compartilhadas gerenciadas por administradores, acessíveis a equipes designadas com permissões e cotas configuráveis",
     "Unset" : "Redefinir",
     "Denied (Inherited permission)" : "Negado (Permissão herdada)",
     "Allowed (Inherited permission)" : "Permitido (Permissão herdada)",
@@ -61,21 +63,6 @@ OC.L10N.register(
     "Add group or team" : "Adicionar grupo ou equipe",
     "{size} used" : "{size} usado",
     "Other …" : "Outros …",
-    "You can not remove your own read permission." : "Você não pode remover sua própria permissão de leitura.",
-    "Group folders" : "Pastas de grupo",
-    "Admin configured folders shared with everyone in a group" : "Pastas configuradas pelo administrador compartilhadas com todos em um grupo",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Pastas configuradas pelo administrador compartilhadas com todos em um grupo.\n\nAs pastas podem ser configuradas em *Pastas de grupo* nas configurações de administrador.\n\nApós a criação de uma pasta, o administrador pode conceder acesso à pasta a um ou mais grupos, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.",
-    "Group folder" : "Pasta de grupo",
-    "Open group folder" : "Abrir pasta de grupo",
-    "List of group folders." : "Lista de pastas de grupo.",
-    "No group folders yet" : "Ainda não há pastas de grupo",
-    "Group folders will show up here" : "As pastas de grupo aparecerão aqui",
-    "Group folder admin delegation" : "Delegação de administrador de pasta de grupo",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "O Nextcloud permite que você delegue a administração de pastas de grupo a usuários não administradores.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Especifique abaixo os grupos que terão permissão para gerenciar pastas de grupos e usar sua API/REST.",
-    "They will have access to all group folders." : "Eles terão acesso a todas as pastas de grupo.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Especifique abaixo os grupos que terão permissão para gerenciar pastas de grupos e usar somente sua API/REST.",
-    "They will only have access to group folders for which they have advanced permissions." : "Eles só terão acesso às pastas de grupo para as quais tenham permissões avançadas.",
     "Admin configured folders shared with everyone in a team" : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe.\n\nAs pastas podem ser configuradas em *Pastas de equipe* nas configurações do administrador.\n\nDepois que uma pasta é criada, o administrador pode conceder acesso à pasta a uma ou mais equipes, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe.\n\nAs pastas podem ser configuradas em *Pastas da equipe* nas configurações do administrador.\n\nDepois que uma pasta é criada, o administrador pode conceder acesso à pasta a uma ou mais equipes, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.\nA partir do Hub 10/Nextcloud 31, o administrador precisa fazer parte da equipe para poder atribuir a ela uma pasta de equipe."
