@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "You cannot remove your own read permission." : "Du kan inte ta bort din egen läsbehörighet.",
     "Team folders" : "Teammappar",
+    "Team Folders" : "Teammappar",
+    "Shared folders managed by admins, accessible to designated teams with configurable permissions and quotas" : "Delade mappar som hanteras av administratörer, tillgängliga för utvalda team med konfigurerbara behörigheter och kvoter",
     "Unset" : "Inaktivera",
     "Denied (Inherited permission)" : "Nekad (ärvd rättighet)",
     "Allowed (Inherited permission)" : "Tillåten (ärvd rättighet)",
@@ -61,21 +63,6 @@ OC.L10N.register(
     "Add group or team" : "Lägg till grupp eller team",
     "{size} used" : "{size} använt",
     "Other …" : "Övrigt ...",
-    "You can not remove your own read permission." : "Du kan inte ta bort din egen läsbehörighet.",
-    "Group folders" : "Gruppmappar",
-    "Admin configured folders shared with everyone in a group" : "Admin-konfigurerade mappar som delas av alla i en grupp",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin-konfigurerade mappar som delas med alla i en grupp.\n\nMappar kan konfigureras från *Gruppmappar* i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till mappen till en eller flera grupper, kontrollera deras skriv/delnings-behörigheter och tilldela en kvot för mappen.",
-    "Group folder" : "Gruppmapp",
-    "Open group folder" : "Öppna gruppmapp",
-    "List of group folders." : "Lista över gruppmappar.",
-    "No group folders yet" : "Inga gruppmappar än",
-    "Group folders will show up here" : "Gruppmappar kommer att visas här",
-    "Group folder admin delegation" : "Administratörsdelegering för gruppmapp",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud tillåter att du delegerar administrationen av gruppmappar till användare som inte är administratörer.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Ange nedan vilka grupper som tillåts hantera gruppmappar och använda dess API/REST.",
-    "They will have access to all group folders." : "De kommer att ha tillgång till alla gruppmappar.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Ange nedan vilka grupper som får hantera gruppmappar och endast använda dess API/REST.",
-    "They will only have access to group folders for which they have advanced permissions." : "De kommer bara att ha tillgång till gruppmappar som de har avancerade behörigheter för.",
     "Admin configured folders shared with everyone in a team" : "Admin-konfigurerade mappar som delas av alla i ett team",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin-konfigurerade mappar som delas med alla i ett team.\n\nMappar kan konfigureras från *Teammappar* i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till mappen till ett eller flera team, kontrollera deras skriv/delnings-behörigheter och tilldela en kvot för mappen.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Administratörskonfigurerade mappar delas med alla i ett team.\n\nMappar kan konfigureras från \"Teammappar\" i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till en eller flera team, kontrollera deras skriv-/delningsbehörigheter och tilldela en kvot för mappen.\nFrån och med Hub 10/Nextcloud 31 måste administratören vara en del av teamet för att kunna tilldela det en Teammapp."
