@@ -63,21 +63,6 @@ OC.L10N.register(
     "Add group or team" : "Додати групу або команду",
     "{size} used" : "{size} використано",
     "Other …" : "Інше ...",
-    "You can not remove your own read permission." : "Ви не можете вилучити дозвіл на читання в себе самого.",
-    "Group folders" : "Групові каталоги",
-    "Admin configured folders shared with everyone in a group" : "Налаштовані адміністратором каталоги, до яких надається спільний доступ всім учасникам групи ",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Адміністратор сконфігурував каталоги, які доступні кожному в групі.\n\nКаталоги можна налаштувати у розділі *Групові каталоги* в адміністративних налаштуваннях.\n\nПісля створення каталогу адміністратор може надати доступ до каталогу одній або декільком групам, визначати їхні дозволи на запис або надання у доступ, квоту для каталогу.",
-    "Group folder" : "Груповий каталог",
-    "Open group folder" : "Відкрити груповий каталог",
-    "List of group folders." : "Перелік групових каталогів.",
-    "No group folders yet" : "Відсутні групові каталоги",
-    "Group folders will show up here" : "Тут показуватимуться групові каталоги",
-    "Group folder admin delegation" : "Повноваження адміністратора групового каталогу",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud дозволяє делегувати адміністрування каталогами команд користувачам без адміністративного рівня доступу.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Зазначте нижче групи, які матимуть право керувати каталогами команд та використовувати їхні API/REST.",
-    "They will have access to all group folders." : "Матимуть доступ до всіх групових каталогів.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Зазначте нижче групи, які матимуть право керувати каталогами команд та використовувати лише їхній API/REST.",
-    "They will only have access to group folders for which they have advanced permissions." : "Матимуть доступ лише до тих групових каталогів, які визначено у розширених повноваженнях.",
     "Admin configured folders shared with everyone in a team" : "Адміністратор сконфігурував каталоги, до яких було надано доступ для всіх у команді",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Адміністратор налаштував спільні каталоги зі всіма у команді.\n\nКаталоги можна налаштувати у розділі адміністративних налаштувань \"Каталоги команди\".\n\nПісля створення каталогу адміністратор може надавати доступ до каталогу одній або кільком командам, контролювати їхні повноваження на запис та надання доступу, визначати квоту каталогу.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Адміністратор налаштував каталоги, якими поділився зі всіма учасниками команди.\n\nКаталоги можна налаштувати у розділі *Каталоги команд* у налаштуваннях адміністрування.\n\nПісля створення каталогу адміністратор може надати доступ до каталогу одній чи більше командам, встановити дозволи на запис/поширення, визначити квоту сховища каталогу.\nВід версіх Hub 10/Nextcloud 31 адміністратор має бути частиною команди, щоби мати право призначиати команду до відповідного каталогу команди."
