@@ -1,5 +1,6 @@
 <?php
 
+declare (strict_types=1);
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -10,6 +11,8 @@ namespace OCA\GroupFolders\Controller;
 use OC\AppFramework\OCS\V1Response;
 use OCA\GroupFolders\Attribute\RequireGroupFolderAdmin;
 use OCA\GroupFolders\Folder\FolderManager;
+use OCA\GroupFolders\Folder\FolderWithMappingsAndCache;
+use OCA\GroupFolders\Mount\FolderStorageManager;
 use OCA\GroupFolders\Mount\MountProvider;
 use OCA\GroupFolders\ResponseDefinitions;
 use OCA\GroupFolders\Service\DelegationService;
@@ -23,6 +26,7 @@ use OCP\AppFramework\OCS\OCSBadRequestException;
 use OCP\AppFramework\OCS\OCSForbiddenException;
 use OCP\AppFramework\OCS\OCSNotFoundException;
 use OCP\AppFramework\OCSController;
+use OCP\Files\Folder;
 use OCP\Files\IRootFolder;
 use OCP\IGroupManager;
 use OCP\IRequest;
@@ -34,10 +38,9 @@ use OCP\IUserSession;
  * @psalm-import-type GroupFoldersCircle from ResponseDefinitions
  * @psalm-import-type GroupFoldersUser from ResponseDefinitions
  * @psalm-import-type GroupFoldersFolder from ResponseDefinitions
- * @psalm-import-type InternalFolderOut from FolderManager
  */
 class FolderController extends OCSController {
-	private ?IUser $user;
+	private readonly ?IUser $user;
 
 	protected const ALLOWED_ORDER_BY = [
 		'mount_point',
@@ -49,13 +52,14 @@ class FolderController extends OCSController {
 	public function __construct(
 		string $AppName,
 		IRequest $request,
-		private FolderManager $manager,
-		private MountProvider $mountProvider,
-		private IRootFolder $rootFolder,
+		private readonly FolderManager $manager,
+		private readonly MountProvider $mountProvider,
+		private readonly IRootFolder $rootFolder,
 		IUserSession $userSession,
-		private FoldersFilter $foldersFilter,
-		private DelegationService $delegationService,
-		private IGroupManager $groupManager,
+		private readonly FoldersFilter $foldersFilter,
+		private readonly DelegationService $delegationService,
+		private readonly IGroupManager $groupManager,
+		private readonly FolderStorageManager $folderStorageManager,
 	) {
 		parent::__construct($AppName, $request);
 		$this->user = $userSession->getUser();
@@ -85,15 +89,19 @@ class FolderController extends OCSController {
 	}
 
 	/**
-	 * @param InternalFolderOut $folder
 	 * @return GroupFoldersFolder
 	 */
-	private function formatFolder(array $folder): array {
-		// keep compatibility with the old 'groups' field
-		$folder['group_details'] = $folder['groups'];
-		$folder['groups'] = array_map(fn (array $group): int => $group['permissions'], $folder['groups']);
-
-		return $folder;
+	private function formatFolder(FolderWithMappingsAndCache $folder): array {
+		return [
+			'id' => $folder->id,
+			'mount_point' => $folder->mountPoint,
+			'quota' => $folder->quota,
+			'acl' => $folder->acl,
+			'size' => $folder->rootCacheEntry->getSize(),
+			'groups' => array_map(fn (array $group): int => $group['permissions'], $folder->groups),
+			'group_details' => $folder->groups,
+			'manage' => $folder->manage,
+		];
 	}
 
 	/**
@@ -122,7 +130,7 @@ class FolderController extends OCSController {
 		}
 
 		$folders = [];
-		foreach ($this->manager->getAllFoldersWithSize($storageId) as $id => $folder) {
+		foreach ($this->manager->getAllFoldersWithSize() as $id => $folder) {
 			// Make them string-indexed for OpenAPI JSON output
 			$folders[(string)$id] = $this->formatFolder($folder);
 		}
@@ -199,10 +207,7 @@ class FolderController extends OCSController {
 			throw new OCSNotFoundException();
 		}
 
-		$folder = $this->manager->getFolder($id, $storageId);
-		if ($folder === null) {
-			throw new OCSNotFoundException();
-		}
+		$folder = $this->checkedGetFolder($id);
 		$folder = $this->formatFolder($folder);
 
 		if (!$this->delegationService->hasApiAccess()) {
@@ -215,18 +220,26 @@ class FolderController extends OCSController {
 		return new DataResponse($folder);
 	}
 
-	/**
-	 * @return DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>|null
-	 */
-	private function checkFolderExists(int $id): ?DataResponse {
-		$storageId = $this->getRootFolderStorageId();
-		if ($storageId === null) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+	private function checkedGetFolder(int $id): FolderWithMappingsAndCache {
+		$folder = $this->manager->getFolder($id);
+		if ($folder === null) {
+			throw new OCSNotFoundException('Groupfolder not found');
 		}
 
-		$folder = $this->manager->getFolder($id, $storageId);
-		if ($folder === null) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		return $folder;
+	}
+
+	private function checkMountPointExists(string $mountpoint): ?DataResponse {
+		$storageId = $this->getRootFolderStorageId();
+		if ($storageId === null) {
+			throw new OCSNotFoundException('Groupfolder not found');
+		}
+
+		$folders = $this->manager->getAllFolders();
+		foreach ($folders as $folder) {
+			if ($folder->mountPoint === $mountpoint) {
+				throw new OCSBadRequestException('Mount point already exists');
+			}
 		}
 
 		return null;
@@ -240,8 +253,10 @@ class FolderController extends OCSController {
 	 * Add a new Groupfolder
 	 *
 	 * @param string $mountpoint Mountpoint of the new Groupfolder
+	 * @param ?string $bucket Overwrite the object store bucket to use for the folder
 	 * @return DataResponse<Http::STATUS_OK, GroupFoldersFolder, array{}>
 	 * @throws OCSNotFoundException Groupfolder not found
+	 * @throws OCSBadRequestException Folder already exists
 	 *
 	 * 200: Groupfolder added successfully
 	 */
@@ -249,19 +264,22 @@ class FolderController extends OCSController {
 	#[RequireGroupFolderAdmin]
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders')]
-	public function addFolder(string $mountpoint): DataResponse {
-
+	public function addFolder(string $mountpoint, ?string $bucket = null): DataResponse {
 		$storageId = $this->rootFolder->getMountPoint()->getNumericStorageId();
 		if ($storageId === null) {
 			throw new OCSNotFoundException();
 		}
 
-		$id = $this->manager->createFolder(trim($mountpoint));
-		$folder = $this->manager->getFolder($id, $storageId);
-		if ($folder === null) {
-			throw new OCSNotFoundException();
+		$this->checkMountPointExists(trim($mountpoint));
+
+		$options = [];
+		if ($bucket) {
+			$options['bucket'] = $bucket;
 		}
 
+		$id = $this->manager->createFolder(trim($mountpoint), $options);
+		$folder = $this->checkedGetFolder($id);
+
 		return new DataResponse($this->formatFolder($folder));
 	}
 
@@ -280,17 +298,9 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'DELETE', url: '/folders/{id}')]
 	public function removeFolder(int $id): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$folder = $this->checkedGetFolder($id);
 
-		$folder = $this->mountProvider->getFolder($id);
-		if ($folder === null) {
-			throw new OCSNotFoundException();
-		}
-
-		$folder->delete();
+		$this->folderStorageManager->deleteStoragesForFolder($folder);
 		$this->manager->removeFolder($id);
 
 		return new DataResponse(['success' => true]);
@@ -301,7 +311,9 @@ class FolderController extends OCSController {
 	 *
 	 * @param int $id ID of the Groupfolder
 	 * @param string $mountPoint New mount point path
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>
+	 * @throws OCSNotFoundException Groupfolder not found
+	 * @throws OCSBadRequestException Mount point already exists
 	 *
 	 * 200: Mount point changed successfully
 	 */
@@ -311,7 +323,11 @@ class FolderController extends OCSController {
 	#[FrontpageRoute(verb: 'PUT', url: '/folders/{id}')]
 	public function setMountPoint(int $id, string $mountPoint): DataResponse {
 		$this->manager->renameFolder($id, trim($mountPoint));
-		return new DataResponse(['success' => true]);
+
+		$folder = $this->checkedGetFolder($id);
+		$this->checkMountPointExists(trim($mountPoint));
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -319,7 +335,7 @@ class FolderController extends OCSController {
 	 *
 	 * @param int $id ID of the Groupfolder
 	 * @param string $group Group to add access for
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
 	 *
 	 * 200: Group access added successfully
 	 * 404: Groupfolder not found
@@ -329,14 +345,13 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders/{id}/groups')]
 	public function addGroup(int $id, string $group): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$this->checkedGetFolder($id);
 
 		$this->manager->addApplicableGroup($id, $group);
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -344,7 +359,7 @@ class FolderController extends OCSController {
 	 *
 	 * @param int $id ID of the Groupfolder
 	 * @param string $group Group to remove access from
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
 	 *
 	 * 200: Group access removed successfully
 	 * 404: Groupfolder not found
@@ -354,14 +369,13 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'DELETE', url: '/folders/{id}/groups/{group}', requirements: ['group' => '.+'])]
 	public function removeGroup(int $id, string $group): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$this->checkedGetFolder($id);
 
 		$this->manager->removeApplicableGroup($id, $group);
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -370,7 +384,7 @@ class FolderController extends OCSController {
 	 * @param int $id ID of the Groupfolder
 	 * @param string $group Group for which the permissions will be set
 	 * @param int $permissions New permissions
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
 	 *
 	 * 200: Permissions updated successfully
 	 * 404: Groupfolder not found
@@ -380,14 +394,13 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders/{id}/groups/{group}', requirements: ['group' => '.+'])]
 	public function setPermissions(int $id, string $group, int $permissions): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$this->checkedGetFolder($id);
 
 		$this->manager->setGroupPermissions($id, $group, $permissions);
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -397,7 +410,7 @@ class FolderController extends OCSController {
 	 * @param string $mappingType Type of the ACL mapping
 	 * @param string $mappingId ID of the ACL mapping
 	 * @param bool $manageAcl Whether to enable or disable the ACL mapping
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
 	 *
 	 * 200: ACL mapping updated successfully
 	 * 404: Groupfolder not found
@@ -407,14 +420,13 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders/{id}/manageACL')]
 	public function setManageACL(int $id, string $mappingType, string $mappingId, bool $manageAcl): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$this->checkedGetFolder($id);
 
 		$this->manager->setManageACL($id, $mappingType, $mappingId, $manageAcl);
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -422,7 +434,7 @@ class FolderController extends OCSController {
 	 *
 	 * @param int $id ID of the Groupfolder
 	 * @param int $quota New quota in bytes
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
 	 *
 	 * 200: New quota set successfully
 	 * 404: Groupfolder not found
@@ -432,14 +444,13 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders/{id}/quota')]
 	public function setQuota(int $id, int $quota): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$this->checkedGetFolder($id);
 
 		$this->manager->setFolderQuota($id, $quota);
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -447,7 +458,7 @@ class FolderController extends OCSController {
 	 *
 	 * @param int $id ID of the Groupfolder
 	 * @param bool $acl Whether ACL should be enabled or not
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
 	 *
 	 * 200: ACL toggled successfully
 	 * 404: Groupfolder not found
@@ -457,14 +468,13 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders/{id}/acl')]
 	public function setACL(int $id, bool $acl): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
-		}
+		$this->checkedGetFolder($id);
 
 		$this->manager->setFolderACL($id, $acl);
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -472,7 +482,9 @@ class FolderController extends OCSController {
 	 *
 	 * @param int $id ID of the Groupfolder
 	 * @param string $mountpoint New Mountpoint of the Groupfolder
-	 * @return DataResponse<Http::STATUS_OK, array{success: true}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{success: true, folder: GroupFoldersFolder}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, list<empty>, array{}>
+	 * @throws OCSNotFoundException Groupfolder not found
+	 * @throws OCSBadRequestException Mount point already exists or invalid mount point provided
 	 *
 	 * 200: Groupfolder renamed successfully
 	 * 404: Groupfolder not found
@@ -482,14 +494,25 @@ class FolderController extends OCSController {
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/folders/{id}/mountpoint')]
 	public function renameFolder(int $id, string $mountpoint): DataResponse {
-		$response = $this->checkFolderExists($id);
-		if ($response) {
-			return $response;
+		$this->checkedGetFolder($id);
+
+		// Check if the new mountpoint is valid
+		if (empty($mountpoint)) {
+			throw new OCSBadRequestException('Mount point cannot be empty');
 		}
 
+		$folder = $this->checkedGetFolder($id);
+
+		if ($folder->mountPoint === trim($mountpoint)) {
+			return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
+		}
+
+		$this->checkMountPointExists(trim($mountpoint));
 		$this->manager->renameFolder($id, trim($mountpoint));
 
-		return new DataResponse(['success' => true]);
+		$folder = $this->checkedGetFolder($id);
+
+		return new DataResponse(['success' => true, 'folder' => $this->formatFolder($folder)]);
 	}
 
 	/**
@@ -501,6 +524,9 @@ class FolderController extends OCSController {
 		if (isset($folderData['id'])) {
 			// single folder response
 			$folderData = $this->folderDataForXML($folderData);
+		} elseif (isset($folderData['folder'])) {
+			// single folder response
+			$folderData['folder'] = $this->folderDataForXML(['folder']);
 		} elseif (is_array($folderData) && count($folderData) && isset(current($folderData)['id'])) {
 			// folder list
 			$folderData = array_map($this->folderDataForXML(...), $folderData);
