@@ -1,4 +1,6 @@
 <?php
+
+declare (strict_types=1);
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -7,7 +9,6 @@
 namespace OCA\GroupFolders\Folder;
 
 use OC\Files\Cache\Cache;
-use OC\Files\Cache\CacheEntry;
 use OC\Files\Node\Node;
 use OCA\Circles\CirclesManager;
 use OCA\Circles\Exceptions\CircleNotFoundException;
@@ -45,23 +46,6 @@ use Psr\Log\LoggerInterface;
  * @psalm-import-type GroupFoldersUser from ResponseDefinitions
  * @psalm-import-type GroupFoldersAclManage from ResponseDefinitions
  * @psalm-import-type GroupFoldersApplicable from ResponseDefinitions
- * @psalm-type InternalFolder = array{
- *   folder_id: int,
- *   mount_point: string,
- *   permissions: int,
- *   quota: int,
- *   acl: bool,
- *   rootCacheEntry: ?CacheEntry,
- * }
- * @psalm-type InternalFolderOut = array{
- *   id: int,
- *   mount_point: string,
- *   groups: array<string, GroupFoldersApplicable>,
- *   quota: int,
- *   size: int,
- *   acl: bool,
- *   manage: list<GroupFoldersAclManage>,
- * }
  * @psalm-type InternalFolderMapping = array{
  *   folder_id: int,
  *   mapping_type: 'user'|'group',
@@ -72,84 +56,86 @@ class FolderManager {
 	public const SPACE_DEFAULT = -4;
 
 	public function __construct(
-		private IDBConnection $connection,
-		private IGroupManager $groupManager,
-		private IMimeTypeLoader $mimeTypeLoader,
-		private LoggerInterface $logger,
-		private IEventDispatcher $eventDispatcher,
-		private IConfig $config,
-		private IUserMappingManager $userMappingManager,
+		private readonly IDBConnection $connection,
+		private readonly IGroupManager $groupManager,
+		private readonly IMimeTypeLoader $mimeTypeLoader,
+		private readonly LoggerInterface $logger,
+		private readonly IEventDispatcher $eventDispatcher,
+		private readonly IConfig $config,
+		private readonly IUserMappingManager $userMappingManager,
 		private readonly FolderStorageManager $folderStorageManager,
 	) {
 	}
 
 	/**
-	 * @return array<int, InternalFolderOut>
+	 * @return array<int, FolderDefinitionWithMappings>
 	 * @throws Exception
 	 */
 	public function getAllFolders(): array {
 		$applicableMap = $this->getAllApplicable();
+		$folderMappings = $this->getAllFolderMappings();
 
 		$query = $this->connection->getQueryBuilder();
 
-		$query->select('folder_id', 'mount_point', 'quota', 'acl')
+		$query->select('folder_id', 'mount_point', 'quota', 'acl', 'storage_id', 'root_id', 'options')
 			->from('group_folders', 'f');
 
 		$rows = $query->executeQuery()->fetchAll();
 
 		$folderMap = [];
 		foreach ($rows as $row) {
-			$id = (int)$row['folder_id'];
-			$folderMap[$id] = [
-				'id' => $id,
-				'mount_point' => $row['mount_point'],
-				'groups' => $applicableMap[$id] ?? [],
-				'quota' => $this->getRealQuota((int)$row['quota']),
-				'size' => 0,
-				'acl' => (bool)$row['acl']
-			];
+			$folder = $this->rowToFolder($row);
+			$id = $folder->id;
+			$folderMap[$id] = FolderDefinitionWithMappings::fromFolder(
+				$folder,
+				$applicableMap[$id] ?? [],
+				$this->getManageAcl($folderMappings[$id] ?? []),
+			);
 		}
 
 		return $folderMap;
 	}
 
-	/**
-	 * @throws Exception
-	 */
-	private function getGroupFolderRootId(int $rootStorageId): int {
-		$query = $this->connection->getQueryBuilder();
-
-		$query->select('fileid')
-			->from('filecache')
-			->where($query->expr()->eq('storage', $query->createNamedParameter($rootStorageId)))
-			->andWhere($query->expr()->eq('path_hash', $query->createNamedParameter(md5('__groupfolders'))));
-
-		return (int)$query->executeQuery()->fetchOne();
-	}
-
-	private function joinQueryWithFileCache(IQueryBuilder $query, int $rootStorageId): void {
-		$conditions = [
-			$query->expr()->eq('c.fileid', 'f.root_id'),
-		];
-		if ($this->connection->getShardDefinition('filecache')) {
-			$conditions[] = $query->expr()->eq('c.storage', $query->createNamedParameter($rootStorageId));
+	private function selectWithFileCache(?IQueryBuilder $query = null): IQueryBuilder {
+		if (!$query) {
+			$query = $this->connection->getQueryBuilder();
 		}
 
-		$query->leftJoin('f', 'filecache', 'c', $query->expr()->andX(...$conditions));
+		$query->select(
+			'f.folder_id',
+			'mount_point',
+			'quota',
+			'acl',
+			'storage_id',
+			'root_id',
+			'options',
+			'c.fileid',
+			'c.storage',
+			'c.path',
+			'c.name',
+			'c.mimetype',
+			'c.mimepart',
+			'c.size',
+			'c.mtime',
+			'c.storage_mtime',
+			'c.etag',
+			'c.encrypted',
+			'c.parent',
+		)
+			->selectAlias('c.permissions', 'permissions')
+			->from('group_folders', 'f')
+			->leftJoin('f', 'filecache', 'c', $query->expr()->eq('c.fileid', 'f.root_id'));
+		return $query;
 	}
 
 	/**
-	 * @return array<int, InternalFolderOut>
+	 * @return array<int, FolderWithMappingsAndCache>
 	 * @throws Exception
 	 */
-	public function getAllFoldersWithSize(int $rootStorageId): array {
+	public function getAllFoldersWithSize(): array {
 		$applicableMap = $this->getAllApplicable();
 
-		$query = $this->connection->getQueryBuilder();
-
-		$query->select('folder_id', 'mount_point', 'quota', 'c.size', 'acl')
-			->from('group_folders', 'f');
-		$this->joinQueryWithFileCache($query, $rootStorageId);
+		$query = $this->selectWithFileCache();
 
 		$rows = $query->executeQuery()->fetchAll();
 
@@ -157,42 +143,38 @@ class FolderManager {
 
 		$folderMap = [];
 		foreach ($rows as $row) {
-			$id = (int)$row['folder_id'];
-			$mappings = $folderMappings[$id] ?? [];
-			$folderMap[$id] = [
-				'id' => $id,
-				'mount_point' => $row['mount_point'],
-				'groups' => $applicableMap[$id] ?? [],
-				'quota' => $this->getRealQuota((int)$row['quota']),
-				'size' => $row['size'] ? (int)$row['size'] : 0,
-				'acl' => (bool)$row['acl'],
-				'manage' => $this->getManageAcl($mappings)
-			];
+			$folder = $this->rowToFolder($row);
+			$id = $folder->id;
+			$folderMap[$id] = FolderWithMappingsAndCache::fromFolderWithMapping(
+				FolderDefinitionWithMappings::fromFolder(
+					$folder,
+					$applicableMap[$id] ?? [],
+					$this->getManageAcl($folderMappings[$id] ?? []),
+				),
+				Cache::cacheEntryFromData($row, $this->mimeTypeLoader),
+			);
 		}
 
 		return $folderMap;
 	}
 
 	/**
-	 * @return array<int, InternalFolderOut>
+	 * @return array<int, FolderWithMappingsAndCache>
 	 * @throws Exception
 	 */
-	public function getAllFoldersForUserWithSize(int $rootStorageId, IUser $user): array {
+	public function getAllFoldersForUserWithSize(IUser $user): array {
 		$groups = $this->groupManager->getUserGroupIds($user);
 		$applicableMap = $this->getAllApplicable();
 
-		$query = $this->connection->getQueryBuilder();
-
-		$query->select('f.folder_id', 'mount_point', 'quota', 'c.size', 'acl')
-			->from('group_folders', 'f')
-			->innerJoin(
-				'f',
-				'group_folders_groups',
-				'a',
-				$query->expr()->eq('f.folder_id', 'a.folder_id')
-			)
+		$query = $this->selectWithFileCache();
+		$query->innerJoin(
+			'f',
+			'group_folders_groups',
+			'a',
+			$query->expr()->eq('f.folder_id', 'a.folder_id'),
+		)
+			->selectAlias('a.permissions', 'group_permissions')
 			->where($query->expr()->in('a.group_id', $query->createNamedParameter($groups, IQueryBuilder::PARAM_STR_ARRAY)));
-		$this->joinQueryWithFileCache($query, $rootStorageId);
 
 		$rows = $query->executeQuery()->fetchAll();
 
@@ -200,17 +182,16 @@ class FolderManager {
 
 		$folderMap = [];
 		foreach ($rows as $row) {
-			$id = (int)$row['folder_id'];
-			$mappings = $folderMappings[$id] ?? [];
-			$folderMap[$id] = [
-				'id' => $id,
-				'mount_point' => $row['mount_point'],
-				'groups' => $applicableMap[$id] ?? [],
-				'quota' => $this->getRealQuota((int)$row['quota']),
-				'size' => $row['size'] ? (int)$row['size'] : 0,
-				'acl' => (bool)$row['acl'],
-				'manage' => $this->getManageAcl($mappings)
-			];
+			$folder = $this->rowToFolder($row);
+			$id = $folder->id;
+			$folderMap[$id] = FolderWithMappingsAndCache::fromFolderWithMapping(
+				FolderDefinitionWithMappings::fromFolder(
+					$folder,
+					$applicableMap[$id] ?? [],
+					$this->getManageAcl($folderMappings[$id] ?? []),
+				),
+				Cache::cacheEntryFromData($row, $this->mimeTypeLoader),
+			);
 		}
 
 		return $folderMap;
@@ -270,7 +251,7 @@ class FolderManager {
 				return [
 					'type' => 'user',
 					'id' => (string)$user->getUID(),
-					'displayname' => (string)$user->getDisplayName()
+					'displayname' => (string)$user->getDisplayName(),
 				];
 			}
 
@@ -283,7 +264,7 @@ class FolderManager {
 				return [
 					'type' => 'group',
 					'id' => $group->getGID(),
-					'displayname' => $group->getDisplayName()
+					'displayname' => $group->getDisplayName(),
 				];
 			}
 
@@ -296,7 +277,7 @@ class FolderManager {
 				return [
 					'type' => 'circle',
 					'id' => $circle->getSingleId(),
-					'displayname' => $circle->getDisplayName()
+					'displayname' => $circle->getDisplayName(),
 				];
 			}
 
@@ -304,19 +285,12 @@ class FolderManager {
 		}, $mappings)));
 	}
 
-	/**
-	 * @return ?InternalFolderOut
-	 * @throws Exception
-	 */
-	public function getFolder(int $id, int $rootStorageId = 0): ?array {
+	public function getFolder(int $id): ?FolderWithMappingsAndCache {
 		$applicableMap = $this->getAllApplicable();
 
-		$query = $this->connection->getQueryBuilder();
+		$query = $this->selectWithFileCache();
 
-		$query->select('folder_id', 'mount_point', 'quota', 'c.size', 'acl')
-			->from('group_folders', 'f')
-			->where($query->expr()->eq('folder_id', $query->createNamedParameter($id, IQueryBuilder::PARAM_INT)));
-		$this->joinQueryWithFileCache($query, $rootStorageId);
+		$query->where($query->expr()->eq('f.folder_id', $query->createNamedParameter($id, IQueryBuilder::PARAM_INT)));
 
 		$result = $query->executeQuery();
 		$row = $result->fetch();
@@ -327,15 +301,16 @@ class FolderManager {
 
 		$folderMappings = $this->getFolderMappings($id);
 
-		return [
-			'id' => $id,
-			'mount_point' => (string)$row['mount_point'],
-			'groups' => $applicableMap[$id] ?? [],
-			'quota' => $this->getRealQuota((int)$row['quota']),
-			'size' => $row['size'] ?: 0,
-			'acl' => (bool)$row['acl'],
-			'manage' => $this->getManageAcl($folderMappings)
-		];
+		$folder = $this->rowToFolder($row);
+		$id = $folder->id;
+		return FolderWithMappingsAndCache::fromFolderWithMapping(
+			FolderDefinitionWithMappings::fromFolder(
+				$folder,
+				$applicableMap[$id] ?? [],
+				$this->getManageAcl($folderMappings),
+			),
+			Cache::cacheEntryFromData($row, $this->mimeTypeLoader),
+		);
 	}
 
 	/**
@@ -391,7 +366,7 @@ class FolderManager {
 				$entry = [
 					'displayName' => $row['group_id'],
 					'permissions' => (int)$row['permissions'],
-					'type' => 'group'
+					'type' => 'group',
 				];
 			} else {
 				$entityId = (string)$row['circle_id'];
@@ -404,7 +379,7 @@ class FolderManager {
 				$entry = [
 					'displayName' => $circle?->getDisplayName() ?? $row['circle_id'],
 					'permissions' => (int)$row['permissions'],
-					'type' => 'circle'
+					'type' => 'circle',
 				];
 			}
 
@@ -415,8 +390,8 @@ class FolderManager {
 	}
 
 	/**
-	 * @throws Exception
 	 * @return list<GroupFoldersGroup>
+	 * @throws Exception
 	 */
 	private function getGroups(int $id): array {
 		$groups = $this->getAllApplicable()[$id] ?? [];
@@ -424,13 +399,13 @@ class FolderManager {
 
 		return array_map(fn (IGroup $group): array => [
 			'gid' => $group->getGID(),
-			'displayname' => $group->getDisplayName()
+			'displayname' => $group->getDisplayName(),
 		], array_values(array_filter($groups)));
 	}
 
 	/**
-	 * @throws Exception
 	 * @return list<GroupFoldersCircle>
+	 * @throws Exception
 	 */
 	private function getCircles(int $id): array {
 		$circles = $this->getAllApplicable()[$id] ?? [];
@@ -454,7 +429,7 @@ class FolderManager {
 
 		return array_map(fn (Circle $circle): array => [
 			'sid' => $circle->getSingleId(),
-			'displayname' => $circle->getDisplayName()
+			'displayname' => $circle->getDisplayName(),
 		], array_values(array_filter(array_merge($circles, $nested))));
 	}
 
@@ -462,6 +437,7 @@ class FolderManager {
 	 * Check if the user is able to configure the advanced folder permissions. This
 	 * is the case if the user is an admin, has admin permissions for the group folder
 	 * app or is member of a group that can manage permissions for the specific folder.
+	 *
 	 * @throws Exception
 	 */
 	public function canManageACL(int $folderId, IUser $user): bool {
@@ -502,8 +478,8 @@ class FolderManager {
 	}
 
 	/**
-	 * @throws Exception
 	 * @return list<GroupFoldersGroup>
+	 * @throws Exception
 	 */
 	public function searchGroups(int $id, string $search = ''): array {
 		$groups = $this->getGroups($id);
@@ -515,8 +491,8 @@ class FolderManager {
 	}
 
 	/**
-	 * @throws Exception
 	 * @return list<GroupFoldersCircle>
+	 * @throws Exception
 	 */
 	public function searchCircles(int $id, string $search = ''): array {
 		$circles = $this->getCircles($id);
@@ -528,8 +504,8 @@ class FolderManager {
 	}
 
 	/**
-	 * @throws Exception
 	 * @return list<GroupFoldersUser>
+	 * @throws Exception
 	 */
 	public function searchUsers(int $id, string $search = '', int $limit = 10, int $offset = 0): array {
 		$groups = $this->getGroups($id);
@@ -542,7 +518,7 @@ class FolderManager {
 					if (!isset($users[$uid])) {
 						$users[$uid] = [
 							'uid' => (string)$uid,
-							'displayname' => $displayName
+							'displayname' => $displayName,
 						];
 					}
 				}
@@ -564,7 +540,7 @@ class FolderManager {
 				if (!isset($users[$uid])) {
 					$users[$uid] = [
 						'uid' => $uid,
-						'displayname' => $member->getDisplayName()
+						'displayname' => $member->getDisplayName(),
 					];
 				}
 			}
@@ -573,92 +549,60 @@ class FolderManager {
 		return array_values($users);
 	}
 
-	/**
-	 * @return list<InternalFolder>
-	 * @throws Exception
-	 */
-	public function getFoldersForGroup(string $groupId, int $rootStorageId = 0): array {
-		$query = $this->connection->getQueryBuilder();
+	private function getFolderOptions(array $row): array {
+		if (!isset($row['options'])) {
+			return [];
+		}
 
-		$query->select(
-			'f.folder_id',
-			'mount_point',
-			'quota',
-			'acl',
-			'c.fileid',
-			'c.storage',
-			'c.path',
-			'c.name',
-			'c.mimetype',
-			'c.mimepart',
-			'c.size',
-			'c.mtime',
-			'c.storage_mtime',
-			'c.etag',
-			'c.encrypted',
-			'c.parent'
-		)
-			->selectAlias('a.permissions', 'group_permissions')
-			->selectAlias('c.permissions', 'permissions')
-			->from('group_folders', 'f')
-			->innerJoin(
-				'f',
-				'group_folders_groups',
-				'a',
-				$query->expr()->eq('f.folder_id', 'a.folder_id')
-			)
-			->where($query->expr()->eq('a.group_id', $query->createNamedParameter($groupId)));
-		$this->joinQueryWithFileCache($query, $rootStorageId);
+		try {
+			$options = json_decode($row['options'], true, 512, JSON_THROW_ON_ERROR);
+		} catch (\JsonException $e) {
+			$this->logger->warning('Error while decoding the folder options', ['exception' => $e, 'folder_id' => $row['folder_id'] ?? 'unknown']);
+			return [];
+		}
 
-		$result = $query->executeQuery()->fetchAll();
+		if (!is_array($options)) {
+			return [];
+		}
 
-		return array_values(array_map(fn (array $folder): array => [
-			'folder_id' => (int)$folder['folder_id'],
-			'mount_point' => (string)$folder['mount_point'],
-			'permissions' => (int)$folder['group_permissions'],
-			'quota' => $this->getRealQuota((int)$folder['quota']),
-			'acl' => (bool)$folder['acl'],
-			'rootCacheEntry' => (isset($folder['fileid'])) ? Cache::cacheEntryFromData($folder, $this->mimeTypeLoader) : null
-		], $result));
+		return $options;
+	}
+
+	private function rowToFolder(array $row): FolderDefinition {
+		return new FolderDefinition(
+			(int)$row['folder_id'],
+			(string)$row['mount_point'],
+			$this->getRealQuota((int)$row['quota']),
+			(bool)$row['acl'],
+			(int)$row['storage_id'],
+			(int)$row['root_id'],
+			$this->getFolderOptions($row),
+		);
 	}
 
 	/**
 	 * @param string[] $groupIds
-	 * @return list<InternalFolder>
+	 * @return list<FolderDefinitionWithPermissions>
 	 * @throws Exception
 	 */
-	public function getFoldersForGroups(array $groupIds, int $rootStorageId = 0): array {
-		$query = $this->connection->getQueryBuilder();
+	public function getFoldersForGroups(array $groupIds, ?int $folderId = null): array {
+		if (count($groupIds) === 0) {
+			return [];
+		}
+		$query = $this->selectWithFileCache();
 
-		$query->select(
-			'f.folder_id',
-			'mount_point',
-			'quota',
-			'acl',
-			'c.fileid',
-			'c.storage',
-			'c.path',
-			'c.name',
-			'c.mimetype',
-			'c.mimepart',
-			'c.size',
-			'c.mtime',
-			'c.storage_mtime',
-			'c.etag',
-			'c.encrypted',
-			'c.parent'
+		$query->innerJoin(
+			'f',
+			'group_folders_groups',
+			'a',
+			$query->expr()->eq('f.folder_id', 'a.folder_id'),
 		)
 			->selectAlias('a.permissions', 'group_permissions')
-			->selectAlias('c.permissions', 'permissions')
-			->from('group_folders', 'f')
-			->innerJoin(
-				'f',
-				'group_folders_groups',
-				'a',
-				$query->expr()->eq('f.folder_id', 'a.folder_id')
-			)
 			->where($query->expr()->in('a.group_id', $query->createParameter('groupIds')));
-		$this->joinQueryWithFileCache($query, $rootStorageId);
+
+		if ($folderId !== null) {
+			$query->andWhere($query->expr()->eq('f.folder_id', $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT)));
+		}
 
 		// add chunking because Oracle can't deal with more than 1000 values in an expression list for in queries.
 		$result = [];
@@ -667,21 +611,21 @@ class FolderManager {
 			$result = array_merge($result, $query->executeQuery()->fetchAll());
 		}
 
-		return array_map(fn (array $folder): array => [
-			'folder_id' => (int)$folder['folder_id'],
-			'mount_point' => (string)$folder['mount_point'],
-			'permissions' => (int)$folder['group_permissions'],
-			'quota' => $this->getRealQuota((int)$folder['quota']),
-			'acl' => (bool)$folder['acl'],
-			'rootCacheEntry' => (isset($folder['fileid'])) ? Cache::cacheEntryFromData($folder, $this->mimeTypeLoader) : null
-		], array_values($result));
+		return array_values(array_map(function (array $row): FolderDefinitionWithPermissions {
+			$folder = $this->rowToFolder($row);
+			return FolderDefinitionWithPermissions::fromFolder(
+				$folder,
+				Cache::cacheEntryFromData($row, $this->mimeTypeLoader),
+				(int)$row['group_permissions']
+			);
+		}, $result));
 	}
 
 	/**
-	 * @return list<InternalFolder>
+	 * @return list<FolderDefinitionWithPermissions>
 	 * @throws Exception
 	 */
-	public function getFoldersFromCircleMemberships(IUser $user, int $rootStorageId = 0): array {
+	public function getFoldersFromCircleMemberships(IUser $user, ?int $folderId = null): array {
 		$circlesManager = $this->getCirclesManager();
 		if ($circlesManager === null) {
 			return [];
@@ -694,71 +638,57 @@ class FolderManager {
 		}
 
 		$queryHelper = $circlesManager->getQueryHelper();
-		$query = $queryHelper->getQueryBuilder();
+		$query = $this->selectWithFileCache($queryHelper->getQueryBuilder());
 
-		$query->select(
-			'f.folder_id',
-			'f.mount_point',
-			'f.quota',
-			'f.acl',
-			'c.fileid',
-			'c.storage',
-			'c.path',
-			'c.name',
-			'c.mimetype',
-			'c.mimepart',
-			'c.size',
-			'c.mtime',
-			'c.storage_mtime',
-			'c.etag',
-			'c.encrypted',
-			'c.parent'
+		$query->innerJoin(
+			'f',
+			'group_folders_groups',
+			'a',
+			$query->expr()->eq('f.folder_id', 'a.folder_id'),
 		)
 			->selectAlias('a.permissions', 'group_permissions')
-			->selectAlias('c.permissions', 'permissions')
-			->from('group_folders', 'f')
-			->innerJoin(
-				'f',
-				'group_folders_groups',
-				'a',
-				$query->expr()->eq('f.folder_id', 'a.folder_id')
-			)
 			->where($query->expr()->neq('a.circle_id', $query->createNamedParameter('')));
 
+		if ($folderId !== null) {
+			$query->andWhere($query->expr()->eq('f.folder_id', $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT)));
+		}
+
 		/** @psalm-suppress RedundantCondition */
 		if (method_exists($queryHelper, 'limitToMemberships')) {
 			$queryHelper->limitToMemberships('a', 'circle_id', $federatedUser);
 		} else {
 			$queryHelper->limitToInheritedMembers('a', 'circle_id', $federatedUser);
 		}
-		$this->joinQueryWithFileCache($query, $rootStorageId);
 
-		return array_map(fn (array $folder): array => [
-			'folder_id' => (int)$folder['folder_id'],
-			'mount_point' => (string)$folder['mount_point'],
-			'permissions' => (int)$folder['group_permissions'],
-			'quota' => $this->getRealQuota((int)$folder['quota']),
-			'acl' => (bool)$folder['acl'],
-			'rootCacheEntry' => (isset($folder['fileid'])) ? Cache::cacheEntryFromData($folder, $this->mimeTypeLoader) : null
-		], array_values($query->executeQuery()->fetchAll()));
+		return array_values(array_map(function (array $row): FolderDefinitionWithPermissions {
+			$folder = $this->rowToFolder($row);
+			return FolderDefinitionWithPermissions::fromFolder(
+				$folder,
+				Cache::cacheEntryFromData($row, $this->mimeTypeLoader),
+				$row['group_permissions']
+			);
+		}, $query->executeQuery()->fetchAll()));
 	}
 
 
 	/**
 	 * @throws Exception
 	 */
-	public function createFolder(string $mountPoint): int {
+	public function createFolder(string $mountPoint, array $options = []): int {
 		$query = $this->connection->getQueryBuilder();
 
 		$query->insert('group_folders')
 			->values([
 				'mount_point' => $query->createNamedParameter($mountPoint),
 				'quota' => self::SPACE_DEFAULT,
+				'options' => $query->createNamedParameter(json_encode([
+					'separate-storage' => true,
+				]))
 			]);
 		$query->executeStatement();
 		$id = $query->getLastInsertId();
 
-		['storage_id' => $storageId, 'root_id' => $rootId] = $this->folderStorageManager->getRootAndStorageIdForFolder($id);
+		['storage_id' => $storageId, 'root_id' => $rootId] = $this->folderStorageManager->initRootAndStorageForFolder($id, true, $options);
 		$query->update('group_folders')
 			->set('root_id', $query->createNamedParameter($rootId))
 			->set('storage_id', $query->createNamedParameter($storageId))
@@ -786,7 +716,7 @@ class FolderManager {
 				'folder_id' => $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT),
 				'group_id' => $query->createNamedParameter($groupId),
 				'circle_id' => $query->createNamedParameter($circleId ?? ''),
-				'permissions' => $query->createNamedParameter(Constants::PERMISSION_ALL)
+				'permissions' => $query->createNamedParameter(Constants::PERMISSION_ALL),
 			]);
 		$query->executeStatement();
 
@@ -802,14 +732,14 @@ class FolderManager {
 		$query->delete('group_folders_groups')
 			->where(
 				$query->expr()->eq(
-					'folder_id', $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT)
-				)
+					'folder_id', $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT),
+				),
 			)
 			->andWhere(
 				$query->expr()->orX(
 					$query->expr()->eq('group_id', $query->createNamedParameter($groupId)),
-					$query->expr()->eq('circle_id', $query->createNamedParameter($groupId))
-				)
+					$query->expr()->eq('circle_id', $query->createNamedParameter($groupId)),
+				),
 			);
 		$query->executeStatement();
 
@@ -827,14 +757,14 @@ class FolderManager {
 			->set('permissions', $query->createNamedParameter($permissions, IQueryBuilder::PARAM_INT))
 			->where(
 				$query->expr()->eq(
-					'folder_id', $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT)
-				)
+					'folder_id', $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT),
+				),
 			)
 			->andWhere(
 				$query->expr()->orX(
 					$query->expr()->eq('group_id', $query->createNamedParameter($groupId)),
-					$query->expr()->eq('circle_id', $query->createNamedParameter($groupId))
-				)
+					$query->expr()->eq('circle_id', $query->createNamedParameter($groupId)),
+				),
 			);
 
 		$query->executeStatement();
@@ -852,7 +782,7 @@ class FolderManager {
 				->values([
 					'folder_id' => $query->createNamedParameter($folderId, IQueryBuilder::PARAM_INT),
 					'mapping_type' => $query->createNamedParameter($type),
-					'mapping_id' => $query->createNamedParameter($id)
+					'mapping_id' => $query->createNamedParameter($id),
 				]);
 		} else {
 			$query->delete('group_folders_manage')
@@ -972,21 +902,23 @@ class FolderManager {
 	}
 
 	/**
-	 * @return list<InternalFolder>
+	 * @return list<FolderDefinitionWithPermissions>
 	 * @throws Exception
 	 */
-	public function getFoldersForUser(IUser $user, int $rootStorageId = 0): array {
+	public function getFoldersForUser(IUser $user, ?int $folderId = null): array {
 		$groups = $this->groupManager->getUserGroupIds($user);
+		/** @var list<FolderDefinitionWithPermissions> $folders */
 		$folders = array_merge(
-			$this->getFoldersForGroups($groups, $rootStorageId),
-			$this->getFoldersFromCircleMemberships($user, $rootStorageId)
+			$this->getFoldersForGroups($groups, $folderId),
+			$this->getFoldersFromCircleMemberships($user, $folderId),
 		);
 
+		/** @var array<int, FolderDefinitionWithPermissions> $mergedFolders */
 		$mergedFolders = [];
 		foreach ($folders as $folder) {
-			$id = $folder['folder_id'];
+			$id = $folder->id;
 			if (isset($mergedFolders[$id])) {
-				$mergedFolders[$id]['permissions'] |= $folder['permissions'];
+				$mergedFolders[$id] = $mergedFolders[$id]->withAddedPermissions($folder->permissions);
 			} else {
 				$mergedFolders[$id] = $folder;
 			}
@@ -1000,15 +932,16 @@ class FolderManager {
 	 */
 	public function getFolderPermissionsForUser(IUser $user, int $folderId): int {
 		$groups = $this->groupManager->getUserGroupIds($user);
+		/** @var list<FolderDefinitionWithPermissions> $folders */
 		$folders = array_merge(
-			$this->getFoldersForGroups($groups),
-			$this->getFoldersFromCircleMemberships($user)
+			$this->getFoldersForGroups($groups, $folderId),
+			$this->getFoldersFromCircleMemberships($user, $folderId),
 		);
 
 		$permissions = 0;
 		foreach ($folders as $folder) {
-			if ($folderId === $folder['folder_id']) {
-				$permissions |= $folder['permissions'];
+			if ($folderId === $folder->id) {
+				$permissions |= $folder->permissions;
 			}
 		}
 
