@@ -1,4 +1,6 @@
 <?php
+
+declare (strict_types=1);
 /**
  * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -8,19 +10,21 @@ namespace OCA\GroupFolders\Trash;
 
 use OCA\Files_Trashbin\Trash\ITrashBackend;
 use OCA\Files_Trashbin\Trash\TrashItem;
-use OCP\Files\FileInfo;
+use OCA\GroupFolders\Folder\FolderDefinitionWithPermissions;
+use OCP\Files\Node;
 use OCP\IUser;
 
 class GroupTrashItem extends TrashItem {
 	public function __construct(
 		ITrashBackend $backend,
-		private string $internalOriginalLocation,
+		private readonly string $internalOriginalLocation,
 		int $deletedTime,
 		string $trashPath,
-		FileInfo $fileInfo,
+		protected Node $fileInfo,
 		IUser $user,
-		private string $mountPoint,
+		private readonly string $mountPoint,
 		?IUser $deletedBy,
+		public readonly FolderDefinitionWithPermissions $folder,
 	) {
 		parent::__construct($backend, $this->mountPoint . '/' . $this->internalOriginalLocation, $deletedTime, $trashPath, $fileInfo, $user, $deletedBy);
 	}
@@ -52,4 +56,20 @@ class GroupTrashItem extends TrashItem {
 
 		return rtrim($path, '.d' . $this->getDeletedTime());
 	}
+
+	public function getFullInternalPath(): string {
+		return parent::getInternalPath();
+	}
+
+	public function getTrashNode(): Node {
+		return $this->fileInfo;
+	}
+
+	public function getGroupTrashFolderStorageId(): int {
+		return $this->fileInfo->getStorage()->getCache()->getNumericStorageId();
+	}
+
+	public function getGroupFolderStorageId(): int {
+		return $this->folder->storageId;
+	}
 }
